<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\SM\Service\Sm00004003ReajusteContratoService as ReajContratoService;

class Sm00004003ReajusteContratoController extends SMCrud
{
    protected $dataSourceName = 'fct_contratoreajuste_widget';
    protected $ReajContratoService;
    
    public function __construct($crudService, $environment, ReajContratoService $ReajContratoService) {
        parent::__construct($crudService, $environment);
        $this->ReajContratoService = $ReajContratoService;
    }
    
    public function save(Request $request, Response $response) {
        
        $request->setParameter('dbname', $this->dataSourceName);
        parent::save($request, $response);
        $response->addDataset(new DataSet('columnsToReturn', $this->crudService->getColumnsToReturn()));
    }
    
    public function find(Request\Filter $request, Response $response) {
    
        $request->setParameter('dbname', $this->dataSourceName);
        parent::find($request, $response);
    }
    
    public function delete(Request $request, Response $response) {
    
        $request->setParameter('dbname', $this->dataSourceName);
        parent::delete($request, $response);
    }
    
    
     /**
     * A função "reajustaContrato" realiza o reajuste do contrato.
     */
    public function reajustaContrato(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrorg    = $this->environment->getNrOrg();
            $operador = $this->environment->getCdOperador();
            
            $this->ReajContratoService->reajustaContrato($row, $nrorg, $operador);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function reajustarMultiplosContratos(Request\DataSet $request, Response $response) {
        try {
            $nrorg = $this->environment->getNrOrg();
            $operador = $this->environment->getCdOperador();

            $rows = $request->getDataSet()->getRows();
            foreach ($rows as $row) {
                $this->ReajContratoService->reajustaContrato($row, $nrorg, $operador);
            }
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function reajustarItensContrato(Request\Row $request, Response $response) {
        try {
            $nrorg = $this->environment->getNrOrg();
            $operador = $this->environment->getCdOperador();

            $row = $request->getRow();
            $this->ReajContratoService->reajustarItensContrato($row, $nrorg, $operador);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    /**
     * Busca o parâmetro de bloqueio de reajuste de contrato e valida se 
     * deve ser realizado o bloqueio.
    **/
    public function validaBloqReajusteContrato(Request\Row $request, Response $response) {
        try {
            $nrorg = $this->environment->getNrOrg();
            $row   = $request->getRow();
            
            $contratos = null;
            if (isset($row["CONTRATOS"])) {
                $contratos = $request->getRow()["CONTRATOS"];
            }

            $valida = $this->ReajContratoService->validaBloqReajusteContrato($nrorg, $contratos);
            
            $response->addDataSet(new DataSet("retorno", array("valida" => $valida)));
            
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    /**
     * Busca o parâmetro de bloqueio de reajuste de contrato e valida se 
     * deve ser realizado o bloqueio INDIVIDUALMENTE para cada contrato.
    **/
    public function validaBloqReajusteContrIndividual(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrseqcontrato   = $row["NRSEQCONTRATO"];
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $nrorg           = $this->environment->getNrOrg();

            $valida = $this->ReajContratoService->validaBloqReajusteContrIndividual($nrorg, $nrseqcontrato, $nrtipoorcamento);
            
            $response->addDataSet(new DataSet("retorno", array("valida" => $valida)));
            
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    /* ==-- Reajusta os contratos em Massa --== */
    public function reajusteContrMassa(Request\Row $request, Response $response) {
        try {
            $contratos = $request->getRow();
            $operador = $this->environment->getCdOperador();            

            $valida = $this->ReajContratoService->reajusteContrMassa($contratos, $operador);
            
            $response->addDataSet(new DataSet("retorno", array("valida" => $valida)));
            
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>